@@ -139,9 +139,9 @@ __END__
 
 Locale::TextDomain::OO::MessagesStruct - Perl Interface extension to use gettext and not mo files
 
-$Id: MessagesStruct.pm 252 2009-12-29 13:55:33Z steffenw $
+$Id: MessagesStruct.pm 271 2010-01-16 07:37:06Z steffenw $
 
-$HeadURL: https://perl-gettext-oo.svn.sourceforge.net/svnroot/perl-gettext-oo/trunk/lib/Locale/TextDomain/OO/MessagesStruct.pm $
+$HeadURL: https://perl-gettext-oo.svn.sourceforge.net/svnroot/perl-gettext-oo/module/trunk/lib/Locale/TextDomain/OO/MessagesStruct.pm $
 
 =head1 VERSION
 
